@@ -1,9 +1,11 @@
 package App::DiffDocText;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-12'; # DATE
+our $DATE = '2022-09-08'; # DATE
 our $DIST = 'App-DiffDocText'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Diff the text of two Office word-processor documents (.doc, .docx, .odt, etc)
@@ -20,7 +22,7 @@ App::DiffDocText - Diff the text of two Office word-processor documents (.doc, .
 
 =head1 VERSION
 
-This document describes version 0.003 of App::DiffDocText (from Perl distribution App-DiffDocText), released on 2021-07-12.
+This document describes version 0.004 of App::DiffDocText (from Perl distribution App-DiffDocText), released on 2022-09-08.
 
 =head1 SYNOPSIS
 
@@ -34,6 +36,41 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-DiffDo
 
 Source repository is at L<https://github.com/perlancar/perl-App-DiffDocText>.
 
+=head1 SEE ALSO
+
+L<App::DiffPDFText>
+
+L<App::DiffXlsText>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-DiffDocText>
@@ -42,15 +79,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
